PoolConfig {

-- The "volatile" property is used to prevent the variable from being
-- saved in the current state.  Voltile is the opposite of persistent.
-- This always must be used when the variable represents an external
-- physical condition, such as the AES/EBU SRC lock.  Here ACMRP has
-- no control over the variable, it must always follow the real thing,
-- not what we might save.  It is also used when it is necessary to
-- track the state of other software (this is kludgey, but it may be
-- best to use ACMRP for communications even though it doesn't maintain
-- the state).  An example of this is "livewire_enable".  Finally,
-- it is used for factory calibration constants.  These are marked volatile
-- and not listed in any storage class.  This means they will never be
-- saved anywhere and will always take on the values specified as
-- defaults in this file.

   -- Identification of the algorithm (set of DSP processing actions)
   -- that these variables control.  It is used to switch algorithms
   -- and as metadata in presets to associate them with the correct algo
   algo_name = { value = "ngfm-5b6b", volatile = true },

   -- The version is also part of the identification (ID matches only if
   -- name and version both match).  It really shouldn't be needed -- prefer
   -- using versioning of individual variables instead.  But, if there was
   -- a large but not complete change, maybe this is the way to go.
   algo_version = { value = 1, min = 0, max = 1e6, volatile = true },


-- last_selected_preset may go away, leaving only float values
-- in the VarPool.  Right now, you can't get at it from the C acmrp_client
-- API.  I keep it in here for convenience in implementing the preset
-- selection stuff in the base_server.
-- This has the string value of the last preset selected by any client
-- It does not mean that the values of all variable will equal those
-- of this preset, because they may have been changed since the last
-- preset selection.
-- You can't change presets by writing to this; you must use the 
-- loadstorage command.  It is not readonly because the storage
-- handler needs to write to it.
   last_selected_preset = { value = "<none>" },
   last_selected_iocfg = { value = "<none>" },

-- You can't change the protection group by writing to this -- must
-- use save command with the pgroup parameter.  This is for reporting
-- the active protection group.
   preset_protection_group = { value = "<none>" },
   preset_protection_mode = { value = "" },

-- Indications of loading of storage classes.  These are set to 1.0
-- before any variable notification caused by the storage load, and
-- are then reset to 0.0 after all notifications.  They may be used
-- for various reasons such as bypassing processing during the
-- change or giving a user feedback indication
   Preset_ld = { val_list = { 0, 1 }, value = 0, volatile=true },
   IO_ld = { val_list = { 0, 1 }, value = 0, volatile=true },
   
-- Overall processing bypass.  Just set this one variable and all
-- processing will be bypassed while the signal continues to be
-- routed through the DSP's.
   overall_proc_bypass = { val_list = { 0, 1 }, value = 0 },
   -- enumerated: 0 = normal, 1 = bypass processing

-- Livewire Enable
   livewire_enable = { val_list = { 0, 1 }, value = 0 },
   -- Made non-volatile becaue IOB needs correct value before FP comes up.
   -- Moreover, there is nothing keeping this variable slaved to the 
   -- lwrp state, so the best we can do for now is to save it independently.

-- For reporting the LiveWire sync status of the IOB.  These are updated
-- not more than a few times a second.
-- Note that these actually could apply to any ONE, not just the IOB, so
-- are misnamed.
   IOB_lwsync_mast = { val_list = { 0, 1 }, value = 0, volatile = true },
   IOB_lwsync_diff = { min = -1536, max = 1536, value = 0, volatile = true },

-- For reporting the link status of the external ethernet switch ports.
-- These are updated when the link status changes.
   O11IO_port2_link = { val_list = { 0, 1 }, value = 0, volatile = true },
   O11IO_port3_link = { val_list = { 0, 1 }, value = 0, volatile = true },

   enet_port2_mode = { val_list = { 0, 1, 2 }, value = 0 },
   -- enumerated: 0=LAN only, 1=normal LW, 2=expansion mode

   patch_mode = { val_list = { 0, 1}, value = 0 },
   -- enumerated: 0=normal processing, 1=insert patch

-- FP AutoLock Enable.  This variable determines if
-- the front panel is automatically locked when the 
-- backlight is turnded off.
   fp_auto_lock = { val_list = { 0, 1 }, value = 0 },
   -- enumerated: 0 = disabled, 1 = enabled

-- Input 
   in_source = { val_list = { 1, 2, 3, 4 }, value = 1 },
   -- enumerated: 1=analog, 2=AES, 3=LiveWire, 4=LiveWire2
   in_patch_src = { val_list = { 1, 2, 3, 4 }, value = 1 },
   -- enumerated: 1=analog, 2=AES, 3=LiveWire, 4=LiveWire2
   in_failover_src = { val_list = { 1, 2, 3, 4 }, value = 1 },
   -- enumerated: 1=analog, 2=AES, 3=LiveWire, 4=Livewire2
   in_failover_time = { min = 0.0, max = 255, value = 0 }, -- seconds
   in_failback_time = { min = 0.5, max = 255, value = 1 }, -- seconds
   in_failover_abs_lvl = { min = -1000, max = 0, value = -50 }, --dBFS
   in_failover_rel_lvl = { min = -144, max = 0, value = -20 }, 
   -- dB ref. secondary signal (how far primary must be below secondary to 
   -- trigger failover logic).
   in_failover_state = { val_list = { 0, 1 }, volatile = true, value = 0 },
   -- enumerated: 0 = normal op, 1 = use failover input
   in_aes_src_lock = { val_list = { 0, 1 }, volatile = true, value = 0 },
   -- enumerated: 0 = sample rate converter PLL unlocked, 1 = locked


   in_ana_mast = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   in_ana_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB
   in_aes_mast = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   in_aes_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB
   patchin_cal1 = { min = -1000.0, max = 6.0, value = 0, volatile = true }, -- dB


   in_lwr_mast = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   in_lwr_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB
   in_lwr2_mast = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   in_lwr2_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB
   O11_in_invert = { val_list = { 0, 1, 2, 3 }, value = 0 },
   --enumerated: 0 = normal, 1 = invert both, 2 = invert L only, 3 = R only
   --in_mtx_LL = { min = -1.0, max = 1.0, value = 1.0}, -- linear mix coef.
   --in_mtx_LR = { min = -1.0, max = 1.0, value = 1.0}, -- linear mix coef.
   --in_mtx_RL = { min = -1.0, max = 1.0, value = 1.0}, -- linear mix coef.
   --in_mtx_RR = { min = -1.0, max = 1.0, value = 1.0}, -- linear mix coef.
   -- Can't use the above from the front panel right now
   O11_in_stereo_mode = { val_list = { 0, 1, 2, 3, 4 }, value = 0 },
   --enumerated 0 = stereo, 1 = mono L, 2 = mono R, 3 = L+R, 4 = swap

-- Output
   O11hdfm_out_ana_select = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor, 3 = Patch Send
   O11hdfm_out_aes1_select = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor, 3 = Patch Send
   O11hdfm_out_aes2_select = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor, 3 = Patch Send
   O11hdfm_out_hph_select = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor, 3 = Patch Send
   O11hdfm_out_lwr1_select = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor, 3 = Patch Send
   O11hdfm_out_lwr2_select = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor, 3 = Patch Send

   O11hdfm_out_hd_pol = { val_list = { -1, 1 }, value = 1 },
   -- -1 to invert polarity relative to FM signal

   O11_out_ana_mast = { min = -1000, max = 22, value = 4 }, -- dBu "peak"
   out_ana_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_ana_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes_mast = { min = -1000.0, max = 0.0, value = -12.0 }, -- dBFS peak
   out_aes_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes2_mast = { min = -1000.0, max = 0.0, value = -12.0 }, -- dBFS peak
   out_aes2_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes2_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_lwr_mast = { min = -1000.0, max = 0.0, value = -12.0 }, -- dBFS peak
   out_lwr_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_lwr_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_lwr2_mast = { min = -1000.0, max = 0.0, value = -12.0 }, -- dBFS peak
   out_lwr2_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_lwr2_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes_srate = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0=int 48k, 1=sync to input, 2=sync to ext, 3=44.1k
   out_aes2_srate = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0=int 48k, 1=sync to input, 2=sync to ext, 3=44.1k

   out_div_delay_time = { min = 0, max = 30, value = 0 }, -- seconds
   out_div_delay_off = { val_list = { 0, 1 }, value = 0 },  

   O11_de_emphasis_ana={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_aes={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_aes2={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_lw={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_lw2={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_hph={ val_list = { 0, 1 }, value = 1 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_doro={ val_list = { 0, 1 }, value = 1 }, --enumerated
   --  1 = on, 0 = off
   patchout_cal1 = { min = -1000, max =40, value = 0}, --dB

-- Patch point bass EQ
   -- This set the EQ on the output.  The input is automatically the inverse.
   patch_gain = { min = -1000.0, max = 12.0, value = -15, volatile=true },-- dB 
   patch_freq = { min = 10, max = 15000, value = 200, volatile=true }, --Hz
   patch_q = { min = 0.01, max = 4, value = 0.4, volatile=true }, -- q
   patch_vtr = { val_list = { 0, 1 }, value = 0 }, -- enumerated
   -- 0 = normal mode (no EQ), 1 = voltair aware (with EQ).

-- BS-412   
   bs412_engage={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   bs412_main_thresh={ min = -3.0, max =9.0, value = 0}, --dB
   bs412_drive = { min = -1000, max = 12, value = 0 }, --dB
   bs412_out_cal = { min = -1000, max = 12, value = 0, volatile=true }, --dB
   bs412_hold = {min = -1000, max = 100, value = 4, volatile=true }, -- dB
   bs412_pkcomp = {min = -100, max = 0, value = 1.5, volatile=true }, -- dB
   bs412_pkcal = {min = -100, max = 50, value = 5, volatile=true }, -- dB

   O11_pre_emphasis={ val_list = { 0, 50, 75 }, value = 75 }, --us
      
   comp_out_lvl = { min = 0, max = 10, value = 5 }, --V
   comp_out_lvl_2 = { min = 0, max = 10, value = 5 }, --V
   sg_pilot_lvl = { min = 0, max = 0.12, value = 0 }, --frac of modulation
   sg_rds_lvl = { min = 0, max = 0.10, value = 0 }, --frac of modulation
   sg_lmr_gain = { min = -1000, max = 6, value = 0 }, --dB
   -- lmr = L - R (separation control).
   ssbsg_pilot_phase ={ min = -180, max = 180,value = 0},--deg
   -- With the new SB SG, this expresses the phase of the pilot relative
   -- to the 38k carrier in degrees @ 19kHz.  Previously, it gave the
   -- phase of the 38k relative to the 19k in degrees @ 38k.  The new
   -- semantics require a name change.
   ssbsg_usb_suppression = { min = 0, max = 1, value = 0 },
   -- 0 gives DSB-SC 1 gives SSB (lower sideband) modulation
--   ssbsg_comp_clip_thresh = { min = -24, max = 0, value = -12 }, --dBFS
   ssbsg_clip_factor_one = { min = 0, max = 1, value = 0.32, volatile=true },
   ssbsg_clip_factor_two = { min = 0, max = 1, value = 0.57, volatile=true },
   -- multiplied by 8 in DSP
   O11_sg_input_calib = { min=-1000, max=6, value = 0.50, volatile=true }, --dB
   O11_sg_comp_clip_drive = { min = -1000, max = 6, value = 0 }, --dB


-- I am putting all the APS stuff right in this file for now.
-- We'll figure out how best to factor it out later.

-- Declipper:
   dclip_engage = { val_list = { 0, 1 }, value = 0 }, -- 0=bypass, 1=engage

-- IO levels

   mas_drive = { min = -1000, max = 18, value = 0 }, -- dB
   mas_rt = { min = -1000, max = 18, value = 0 }, -- dB

-- Input filtering
   hpf_filter_freq = { min = 0, max = 20000, value = 0 },
   -- currently implemented values are OUT, 20, 30, 40 and 70 Hz

   lpf_on = { val_list = { 0, 1 },
   		       	   value = 1 },

--Phase Rotator
   phase_rot_style = { val_list = { 0, 1, 2, 3 },
   		       	   value = 0 },
   -- 0 = none, 1 = hybrid, 2 = fully tunable, 3 = standard

---------------------------- wideband AGC --------------------------------
   wbagc_engage = { val_list = { 0, 1 }, value = 0 },
   -- 0 = wbagc bypassed, 1 = wbagc engaged
   wbagc_drive = { min = -1000.0, max = 122.0, value = 0.0 }, -- dB

--[[
   -- In the DSP:
   -- "wbagc_att" is 
   -- the "base" value attack input into a standard first order,
   -- exponential att/rel.  There is an acceleration automatically applied
   -- to this attack when the audio exceeds 
   -- a secondary threshold (attack2_thresh, below)
   -- "wbagc_att_lf_cal" and "wbagc_att_hf_cal": 
   -- These two multiply the the attack value before it is applied to 
   -- the time constants.
   -- As it is currently implemented, the "cal" parameters are very small
   -- corresponding to the coefficients needed to realize the long
   -- RC-equiv TC's.  the "att" is a multiplier used to scale both.
   -- So, we can do it this way:
--]]
--[[
   wbagc_att_mult = { min = 1/1024, max = 1024, value = 1 }, -- unitless
   wbagc_att_lf_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   -- RC-equivalent TC
   wbagc_att_hf_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   -- RC-equivalent TC
--]]

   -- Alternately, we could make the "att" the actual TC value
   -- and the "cal" into multipliers:
   wbagc_attack = { min = 0.1, max = 174760, value = 5000 }, -- ms
   wbagc_att_lf_cal = { min = 1/1024, max = 1024, value = 0.07, volatile=true }, -- unitless

   wbagc_trans = { min = 0.0001, max = 10, value = 0.6, volatile=true }, --unitless

--[[
   The release works similarly to the attack.  But, instead of having an
   acceleration function, the release may be switched to a release2 or
   to a window release under certain conditions.  These are both specified
   as multipliers to the main release (affecting both sidechain bands).
--]]
   wbagc_release = { min = 0.1, max = 174760, value = 10000 }, -- ms
   wbagc_arcalb = { min = 0.0001, max = 1000, value = .25, volatile=true }, --unitless

   -- Thresholds:  the "off"sets are specified relative to the main thresh
   wbagc_main_thresh = { min = -1000.0, max = 0.0, value = -12, volatile=true }, -- dBr1
   wbagc_gate_thresh = { min = -1000.0, max = 0.0, value = 0.0 }, -- dBr1
   -- gain lock threshold

   wbagc_window = { min = -1000, max = 1000, value = 0.0 }, --dB
   wbagc_ratio = { min = 0, max = 0.1, value = 0.01 }, -- hyperbolic


   wbagc_at2thresh = {min = -100, max = 50, value = 7, volatile=true }, -- dB 
   wbagc_at2max = { min = 0.0001, max = 174760, value = 35, volatile=true }, -- ms
   wbagc_armax = { min = 0, max = 1, value = 0.15, volatile=true }, -- hyperbolic 


   wbagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   wbagc_rtp_speed = { min = 0.1, max = 174760, value = 10000 }, -- ms
   -- This is just another exponential attack TC, we specify it same as others

   wbagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   wbagc_acc_rels = { min = 1.2, max = 10, value = 1.2 }, -- release acceleration factor
   wbagc_ref_off = { min = 0, max = 1, value = 0.6 }, --unitless
   wbagc_gate_cal = { min = 0, max = 35, value = 4, volatile=true }, --dB
   wbagc_arsense = { min = .001, max = 20, value = 10, volatile=true }, -- unitless

   wbagc_bypgain ={ min = -1000.0, max = 20, value = 0, volatile=true},
    --dB

   wbagc_at2scale ={ min = .000000001, max = 1, value = 0.01, volatile=true}, -- unitless
   wbagc_wacc = { min = 0.1, max = 174760, value = 500, volatile=true }, -- ms 
   wbagc_wdec = { min = 0.1, max = 174760, value = 2500, volatile=true }, -- ms

   wbagc_rtpdef = { val_list = { 0, 1 },
                                 value = 0},
   wbagc_mode = { val_list = { 0, 1 },
                                 value = 1, volatile=true},

   wbagc_outcal = { min = -1000.0, max = 20, value = 0, volatile=true }, -- dB

----------------------------------end wbagc-----------------------------------
----------------------------------Dynamic EQ----------------------------------
   dyneq_eng = { val_list = { 0, 1 },

                      value = 0},
   dyneq_sh = { min = -6.0, max = 6.0, value = 0.0 }, -- dB
   dyneq_hf = { min = -6.0, max = 6.0, value = 0.0 }, -- dB
   dyneq_pf = { min = -6.0, max = 6.0, value = 0.0 }, -- dB 
   dyneq_lf = { min = -6.0, max = 6.0, value = 0.0 }, -- dB
   dyneq_mf = { min = 0.0, max = 0.0, value = 0.0 }, -- dB
   dyneq_rng = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB (currently unused)

   dyneq_sh_cutr = { min = -1000, max = 12.0, value = 0.0 }, -- comp ratio
   dyneq_hi_cutr = { min = -1000, max = 12.0, value = 0.0 }, -- comp ratio
   dyneq_mh_cutr = { min = -1000, max = 12.0, value = 0.0 }, -- comp ratio
   dyneq_lo_cutr = { min = -1000, max = 12.0, value = 0.0 }, -- comp ratio
   
   dyneq_sh_boostr = { min = 0.0, max = 2.0, value = 1.0 }, -- comp ratio
   dyneq_hi_boostr = { min = 0.0, max = 2.0, value = 1.0 }, -- comp ratio
   dyneq_mh_boostr = { min = 0.0, max = 2.0, value = 1.0 }, -- comp ratio
   dyneq_lo_boostr = { min = 0.0, max = 2.0, value = 0.7 }, -- comp ratio

   dyneq_sh_targ_sep = { min = -24.0, max = 12.0, value = -3, volatile = true }, -- dBr
   dyneq_sh_targ_chained = { min = -24.0, max = 12.0, value = 0.0, volatile = true }, -- dBr
   dyneq_hf_targ_sep = { min = -24.0, max = 12.0, value = -3, volatile = true }, -- dBr
   dyneq_hf_targ_chained = { min = -24.0, max = 12.0, value = 0.0, volatile = true }, -- dBr
   dyneq_pf_targ = { min = -24.0, max = 12.0, value = 0.0, volatile = true }, -- dBr 
   dyneq_lf_targ = { min = -24.0, max = 12.0, value = 1.0, volatile = true }, -- dBr
   dyneq_lf_cal = { min = -24.0, max = 12.0, value = 5.0, volatile = true }, -- dBr

   dyneq_lo_mxratio = { min = 0.0, max = 10.0, value = 1.0, volatile = true }, -- mix ratio
   dyneq_mh_mxratio = { min = 0.0, max = 10.0, value = 1.0, volatile = true }, -- mix ratio
   dyneq_hi_mxratio = { min = 0.0, max = 10.0, value = 1.0, volatile = true }, -- mix ratio
   dyneq_sh_mxratio = { min = 0.0, max = 10.0, value = 1.0, volatile = true }, -- mix ratio

   
   dyneq_mode = { val_list = { 0, 1 }, value = 1},

   dyneq_hicomp1k = { min = -1000.0, max = 12.0, value = -6.0, volatile = true }, -- dB
   dyneq_hicomp2k = { min = -1000.0, max = 12.0, value = 0.0, volatile = true }, -- dB
   dyneq_hicomp3k = { min = -1000.0, max = 12.0, value = 0.0, volatile = true }, -- dB 

----------------------------------end Dynamic EQ------------------------------
----------------------------------mbagc crossovers----------------------------

   loagc_xovr= { val_list = { 190, 150, 120 }, value = 150 }, -- Hz
   mlagc_xovr = { val_list = { 700, 450 }, value = 450 }, -- Hz
   mhagc_xovr = { val_list = { 1000, 2500, 3500 }, value = 2500 }, --Hz

   mbagc_sync_mode = { val_list = { 0, 1 },
   		       	   value = 0 },
   --  1 = band 3 ref, 0 = band 2 ref

   mbagc_engage= { val_list = { 0, 1 },
   		       	   value = 1 },
  --  1 = engage, 0 = bypass


----------------------------------mbagc---------------------------------------

-- Mix And Drives

   mbagc_drive = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   mbagc_transdet = { min = -1000.0, max = 30.0, value = -1000 }, -- dB
   mlagc_transdet = { min = -1000.0, max = 30.0, value = 0 }, -- dB
   loagc_transdet = { min = -1000.0, max = 30.0, value = 0 }, -- dB  

   mbagc_dcal = { min = -1000.0, max = 100.0, value = 25 }, -- dB	

   shagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   hiagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   hiagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   mhagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   mlagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   loagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   shagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   hiagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   mhagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   mlagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   loagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

-- Output Calibration

   mbagc_ocal = { min = -1000.0, max = 50.0, value = -18 }, -- dB, 
  

--ratios

   shagc_ratio = { min = 0.001, max = 0.1, value = 0.1 }, --hyperbolic
   hiagc_ratio = { min = 0.001, max = 0.1, value = 0.1 }, --hyperbolic
   mhagc_ratio = { min = 0.001, max = 0.1, value = 0.1 }, --hyperbolic
   mlagc_ratio = { min = 0.001, max = 0.1, value = 0.1 }, --hyperbolic
   loagc_ratio = { min = 0.001, max = 0.1, value = 0.1 }, --hyperbolic

-- Thresholds

   shagc_thresh = { min = -1000.0, max = 1000.0, value = 10  }, -- dB
   hiagc_thresh = { min = -1000.0, max = 1000.0, value = 0  }, -- dB
   mhagc_thresh = { min = -1000.0, max = 1000.0, value = 0  }, -- dB
   mlagc_thresh = { min = -1000.0, max = 1000.0, value = 2  }, -- dB
   loagc_thresh = { min = -1000.0, max = 1000.0, value = 2  }, -- dB


---multiband RTP

   shagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   shagc_rtp_speed = { min = 0.1, max = 174760, value = 10000 }, -- ms

   hiagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   hiagc_rtp_speed = { min = 0.1, max = 174760, value = 10000 }, -- ms

   mhagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   mhagc_rtp_speed = { min = 0.1, max = 174760, value = 10000 }, -- ms

   mlagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   mlagc_rtp_speed = { min = 0.1, max = 174760, value = 10000 }, -- ms

   loagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   loagc_rtp_speed = { min = 0.1, max = 174760, value = 10000 }, -- ms

-- Windowing

   shagc_window = { min = -1000, max = 1000, value = 0.0 }, --dB
   hiagc_window = { min = -1000, max = 1000, value = 0.0 }, --dB
   mhagc_window = { min = -1000, max = 1000, value = 0.0 }, --dB
   mlagc_window = { min = -1000, max = 1000, value = 0.0 }, --dB
   loagc_window = { min = -1000, max = 1000, value = 0.0 }, --dB

  shagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat
  hiagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat
  mhagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat
  mlagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat
  loagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat

-- Auto attack

   shagc_at2thresh = {min = -100, max = 50, value = 45, volatile=true }, -- dB
   hiagc_at2thresh = {min = -100, max = 50, value = 35, volatile=true }, -- dB 
   mhagc_at2thresh = {min = -100, max = 50, value = 35, volatile=true }, -- dB
   mlagc_at2thresh = {min = -100, max = 100, value = 50, volatile=true }, -- dB 
   loagc_at2thresh = {min = -100, max = 200, value = 100, volatile=true }, -- dB

   shagc_at2max = { min = 0.1, max = 174760, value = 1000, volatile=true }, -- ms
   hiagc_at2max = { min = 0.1, max = 174760, value = 1200, volatile=true }, -- ms
   mhagc_at2max = { min = 0.1, max = 174760, value = 2000, volatile=true }, -- ms
   mlagc_at2max = { min = 0.1, max = 174760, value = 3000, volatile=true }, -- ms
   loagc_at2max = { min = 0.1, max = 174760, value = 5000, volatile=true }, -- ms

   shagc_trans = { min = 0.0001, max = 10, value = 1.0, volatile=true }, --unitless
   hiagc_trans = { min = 0.0001, max = 10, value = 1.0, volatile=true }, --unitless
   mhagc_trans = { min = 0.0001, max = 10, value = 1.0, volatile=true }, --unitless
   mlagc_trans = { min = 0.0001, max = 10, value = 1.0, volatile=true }, --unitless
   loagc_trans = { min = 0.0001, max = 1000, value = 1.0, volatile=true }, --unitless

-- Synchronization (Smart Coupling) and other things

   mbagc_sync = { min = -1000.0, max = 0.0, value = -1.4 }, -- dB
   loagc_sync = { min = -1000.0, max = 0.0, value = 0.0 }, -- dB

   mas_intelligate = { min = -1000, max = 12, value = 0.0 }, -- dB
   shagc_intelligate = { min = -1000, max = 12, value = -8 }, -- dB
   hiagc_intelligate = { min = -1000, max = 12, value = -10 }, -- dB
   mhagc_intelligate = { min = -1000, max = 12, value = -10}, -- dB

-- Gating

   mbagc_gate_thresh = { min = -1000.0, max = 0.0, value = -15 }, -- dBr1

   shagc_gate_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB
   hiagc_gate_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB
   mhagc_gate_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB
   mlagc_gate_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB
   loagc_gate_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB

-- Time Constants

   mbagc_release = { min = 1/1024, max = 1024, value = 1 }, -- unitless
   shagc_rel_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   hiagc_rel_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   mhagc_rel_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   mlagc_rel_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   loagc_rel_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms

   mbagc_multf = {min = 0.0001, max = 1, value = 0.1 }, -- unitless

   mbagc_attack = { min = 1/1024, max = 1024, value = 0.095 }, -- unitless

   shagc_att_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   hiagc_att_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   mhagc_att_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   mlagc_att_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   loagc_att_cal = { min = 0.1, max = 174760, value = 10000 }, -- ms
   
   shagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   hiagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   mhagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   mlagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   loagc_makeup = { min = -120, max = 1, value = -7 }, --dB

   shagc_acc_rel = { min = 1.2, max = 5, value = 1.2 }, --Mult Factor
   hiagc_acc_rel = { min = 1.2, max = 5, value = 1.2 }, --Mult Factor
   mhagc_acc_rel = { min = 1.2, max = 5, value = 1.2 }, --Mult Factor
   mlagc_acc_rel = { min = 1.2, max = 5, value = 1.2 }, --Mult Factor
   loagc_acc_rel = { min = 1.2, max = 5, value = 1.2 }, --Mult Factor


   shagc_gbgo = { min = -1000, max = 1000, value = -20.0, volatile=true }, --dBr1
   hiagc_gbgo = { min = -1000, max = 1000, value = -10.0, volatile=true }, --dBr1
   mhagc_gbgo = { min = -1000, max = 1000, value = -2.0, volatile=true }, --dBr1

   shagc_dcomp = { min = -0.0, max = 0.0, value = 0.0 }, -- dB
   cham_mode = { val_list = { 0, 1, 2 }, value = 0 },

   mbagc_bypgain = { min = -0.0, max = 30.0, value = 30.0, volatile=true }, -- dB 

----------------------------------end mbagc-----------------------------------





----------------------------------enhancers-----------------------------------

   hi_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   md_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   lo_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   hi_freq = { min = 0, max = 17000, value = 5000 }, --Hz
   md_freq = { min = 0, max = 17000, value = 1000 }, --Hz
   lo_freq = { min = 0, max = 17000, value = 80 }, --Hz
   hi_q = { min = 0.001, max = 4, value = 1.0 }, -- q
   md_q = { min = 0.001, max = 4, value = 1.0 }, -- q
   lo_q = { min = 0.001, max = 4, value = 1.0 }, -- q

   -- Shelving filters below: called lf (low shelf) and hf (high shelf)
   lf_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   hf_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   lf_freq = { min = 10, max = 15000, value = 100 }, --Hz
   hf_freq = { min = 10, max = 15000, value = 8000 }, --Hz
   lf_q = { min = 0.01, max = 4, value = 0.707 }, -- q
   hf_q = { min = 0.01, max = 4, value = 0.707 }, -- q

   air_eng = { val_list = { 0, 1 }, value = 0}, --boolean

  
   air_mxratio = { min = 0.0, max = 10.0, value = 1.0, volatile = true }, -- mix ratio

   dbass_boost = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   wbass_boost = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   dbass_ratio = { min = 0.1, max = 1.0, value = 0.1 }, -- unitless
   wbass_ratio = { min = 0.1, max = 1.0, value = 0.1 }, -- unitless
   para_byp = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = EQ ON, 1 = EQ Defeat

   ben_byp = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = BEN ON, 1 = BEN Defeat


   bass_enh = { min = -120, max = 12.0, value = 3.0 }, -- dB

   dbass_mode = { val_list = { 0, 1 },
   		       	   value = 1 },

   wbass_mode = { val_list = { 0, 1 },
   		       	   value = 1 },

   stereo_enh = { min = 0, max = 2.0, value = -12 }, --unitless


   phb_thresh = { min = -120.0, max = 12.0, value = 0.0 }, --dB
   benh_sl = { val_list = { 12, 24 },
   		       	   value = 12 },
   -- 12 = 12dB-oct, 24 = 24dB -oct
   basssq = { min = -120.0, max = 5.0, value = 0.0 }, --dB

   bass_mode = { val_list = { 0, 1 },
   		       	   value = 0 },

--------------------------------MB Limiters-----------------------------------

   shlim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   hilim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   mhlim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   mllim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   lolim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   sllim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   lim_drive = { min = -1000.0, max = 122.0, value = 0.0 }, -- dB

   -- These control the window and modify the TC value.  We can
   -- describe the window value exactly:
   lf_lim_density = { min = -20, max = 0, value = -8 },  -- dB
   hf_lim_density = { min = -20, max = 0, value = -8 },  -- dB

   shlim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   hilim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   mhlim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   mllim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   lolim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   sllim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
 
   mhlim_dcomp = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   hilim_dcomp = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   sllim_dcomp = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   shlim_dcomp = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   shlim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   hilim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   mhlim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   mllim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   lolim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   sllim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB

   shlim_load = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   hilim_load = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   mhlim_load = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   mllim_load = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   lolim_load = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   sllim_load = { min = -12.0, max = 20.0, value = 0.0 }, -- dB

   lim_sidemast = { min = -1000.0, max = 122.0, value = 25, volatile=true }, -- dB

   shlim_scg = { min = -100.0, max = 100.0, value = 3.0, volatile=true }, 
   -- dB
   hilim_scg = { min = -100.0, max = 100.0, value = 2.0, volatile=true }, 
   -- dB
   mhlim_scg = { min = -100.0, max = 100.0, value = 2.0, volatile=true }, 
   -- dB
   mllim_scg = { min = -100.0, max = 100.0, value = 2.0, volatile=true }, 
   -- dB
   lolim_scg = { min = -100.0, max = 100.0, value = 2.0, volatile=true }, 
   -- dB
   sllim_scg = { min = -100.0, max = 100.0, value = 2.0, volatile=true }, 
   -- dB

   lim_release = { min = 1/1024, max = 1024, value = 1 }, -- unitless

   shlim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   hilim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   mhlim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   mllim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   lolim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   sllim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms


   lim_attack = { min = 1/1024, max = 1024, value = 1 }, -- unitless

   shlim_att_cal = { min = 0.1, max = 174760, value = 200 }, -- ms 
   hilim_att_cal = { min = 0.1, max = 174760, value = 200 }, -- ms
   mhlim_att_cal = { min = 0.1, max = 174760, value = 200 }, -- ms
   mllim_att_cal = { min = 0.1, max = 174760, value = 200 }, -- ms
   lolim_att_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   sllim_att_cal = { min = 0.1, max = 174760, value = 800 }, -- ms

   -- RCD: Note: these are actually the thresholds at which 
   -- att2 starts to kick in:
   shlim_att2 = { min = -1000, max = 70, value = 30, volatile=true }, --dB
   hilim_att2 = { min = -1000, max = 70, value = 30, volatile=true }, --dB
   mhlim_att2 = { min = -1000, max = 70, value = 40, volatile=true }, --dB
   mllim_att2 = { min = -1000, max = 70, value = 50, volatile=true }, --dB
   lolim_att2 = { min = -1000, max = 70, value = 80, volatile=true }, --dB
   sllim_att2 = { min = -1000, max = 500, value = 350, volatile=true }, --dB
   

   -- RCD: These are scale factors that modify action of the
   -- actual time constant constants hard-coded in DSP.
   shlim_frel = { min = 0.0001, max = 1, value = 0.75 }, -- unitless
   hilim_frel = { min = 0.0001, max = 1, value = 0.65 }, -- unitless
   mhlim_frel = { min = 0.0001, max = 1, value = 0.6 }, -- unitless
   mllim_frel = { min = 0.0001, max = 1, value = 0.6 }, -- unitless
   lolim_frel = { min = 0.0001, max = 1, value = 0.55 }, -- unitless
   sllim_frel = { min = 0.0001, max = 1, value = 0.55 }, -- unitless
   
   -- RCD: These are TC's  24kS/s
   shlim_platt = {min = 4.2, max = 174760, value = 35, volatile=true }, -- ms
   hilim_platt = {min = 4.2, max = 174760, value = 500, volatile=true }, -- ms
   mhlim_platt = {min = 4.2, max = 174760, value = 3000, volatile=true }, -- ms
   mllim_platt = {min = 4.2, max = 174760, value = 7500, volatile=true }, -- ms
   lolim_platt = {min = 4.2, max = 174760, value = 9000, volatile=true }, -- ms
   sllim_platt = {min = 4.2, max = 174760, value = 12000, volatile=true }, -- ms
 
   shlimit_maxatt = { min = 0.1, max = 174760, value = 50, volatile=true }, -- ms
   hilimit_maxatt = { min = 0.1, max = 174760, value = 65, volatile=true }, -- ms
   mhlimit_maxatt = { min = 0.1, max = 174760, value = 70, volatile=true }, -- ms
   mllimit_maxatt = { min = 0.1, max = 174760, value = 80, volatile=true }, -- ms  
   lolimit_maxatt = { min = 0.1, max = 174760, value = 50000, volatile=true }, -- ms
   sllimit_maxatt = { min = 0.1, max = 174760, value = 100000, volatile=true }, -- ms

   shlim_ratio = { min = 0.000001, max = 1, value = 1 }, -- hyperbolic
   hilim_ratio = { min = 0.000001, max = 1, value = 1 }, -- hyperbolic
   mhlim_ratio = { min = 0.000001, max = 1, value = 1 }, -- hyperbolic
   mllim_ratio = { min = 0.000001, max = 1, value = 1 }, -- hyperbolic
   lolim_ratio = { min = 0.000001, max = 1, value = 1 }, -- hyperbolic
   sllim_ratio = { min = 0.000001, max = 1, value = 1 }, -- hyperbolic

   mllim_compat_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   lf_boost = { val_list = { 0, 1, 2 }, value = 0 },
   hf_enh = { val_list = { 0, 1 }, value = 0 },

------------------------------------ HD EQ -----------------------------------

   hdpara_byp = { val_list = { 0, 1 }, value = 0 },
   
   HD_hi_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   HD_md_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   HD_lo_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   HD_hi_freq = { min = 10, max = 15000, value = 5000 }, --Hz
   HD_md_freq = { min = 10, max = 15000, value = 1000 }, --Hz
   HD_lo_freq = { min = 10, max = 15000, value = 200 }, --Hz
   HD_hi_q = { min = 0.01, max = 4, value = 1.0 }, -- q
   HD_md_q = { min = 0.01, max = 4, value = 1.0 }, -- q
   HD_lo_q = { min = 0.01, max = 4, value = 1.0 }, -- q

   -- Shelving filters below: called lf (low shelf) and hf (high shelf)
   HD_lf_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   HD_hf_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   HD_lf_freq = { min = 10, max = 15000, value = 100 }, --Hz
   HD_hf_freq = { min = 10, max = 15000, value = 8000 }, --Hz
   HD_lf_q = { min = 0.01, max = 4, value = 0.707 }, -- q
   HD_hf_q = { min = 0.01, max = 4, value = 0.707 }, -- q


------------------------------Front End Clipper System----------------------


   clip_drive = { min = -120, max = 6.0, value = 0.0 }, --dB
   clip_ofst = { min = -120, max = 0, value = 0.0 }, -- dB
   bc_opthresh = { min = -1000, max = 0.0, value = -8.0, volatile=true }, --dB
   bc_skew = { min = -3, max = 6.0, value = 0.0 }, --dB
   bc_cal = { min = -1000, max = 12.0, value = -18.5, volatile=true }, --dB
   abc_thresh = { min = -1000, max = 0.0, value = -30, volatile=true }, --dB
   abc_tight = { min = 0.5, max = 1, value = 1 }, --relative
   bc_dyn_sens = { min = -1000, max = 40, value = 35, volatile=true }, --dB
   abc_hf_cal = { min = -1000, max = 100.0, value = 30, volatile=true }, --dB  
   bc_dyn_thresh = { min = -120, max = 6.0, value = 6.0 }, --dB   
   bc_depth = { min = -120, max = 5, value = 0.0 }, -- dB 

   abc_hi_freq = { min = 10, max = 15000, value = 10000, volatile=true }, --Hz
   abc_hi_q = { min = 0.01, max = 4, value = 0.2, volatile=true }, -- q  
   abc_hi_gain = { min = -1000.0, max = 25.0, value = 0.0 }, -- dB

   abc_hithresh = {min = -100, max = 100, value = 1.0, volatile=true },--dB
   abc_sthresh = {min = -100, max = 100, value = 2.5, volatile=true },--dB
   bass_enh_att = { min = 0.1, max = 174760, value = 250 }, -- ms
   bc_style = { val_list = { 0, 1 }, value = 1 },
   w_bass_drive= { min = -120.0, max = 12.0, value = 0.0 }, --dB
   phat_bass= { min = -120.0, max = 0.0, value = -20.0 }, --dB
   phat_phase={ val_list = { 0, 1 }, value = 1 }, -- boolian
   phat_uhar= { min = -120.0, max = 6.0, value = -80.0 }, --dB
   bassclip_out_cal = { min = -122.0, max = 0.0, value = -22.5, volatile = true }, --dB
   bc_smooth = { min = 0.0001, max = 12.0, value = 5 }, --unitless
   abc_rel = { min = 1, max = 100000, value = 160, volatile=true }, --ms
   abc_att = { min = 1, max = 100000, value = 25 }, --ms

   clipper_silk = { min = 0.01, max = 2.9, value = 0.05 }, -- relative
   clipper_hf_silk = { min = 0.5, max = 1, value = 1 }, -- relative
   clipper_um_silk = { min = 0.01, max = 2.9, value = 1 }, -- relative
   clipper_sh_silk = { min = 0.01, max = 1, value = 1 }, -- relative
   clipper_sh_hdrm = { min = 0.01, max = 1, value = 1 }, -- relative
   hf_silk_mode = { val_list = { 0, 1 }, value = 0}, --boolean

   pepino_ver = { val_list = { 1, 2, 3 }, value = 1},	

   hd_cal = { min = -120.0, max = 12.0, value = 0.0 }, --dB
  
   mono_gain = { min = -120, max = 3.0, value = -3.0 }, --dB
   bc_fix_thresh = { min = -120, max = 12.0, value = -2.5 }, --dB
   hdlim_drive = { min = -120, max = 30.0, value = 0, volatile=true }, --dB 

   bc_meter = { val_list = { 0, 1 }, value = 1 },
   -- 0 = ctl, 1 = Clip Depth 

  

------------------------------System Params----------------------------------

   bc_fixed_cal = { min = -1000.0, max = 12.0, value = -10, volatile=true }, -- dB
   bc2_mthresh = { min = -1000.0, max = 12, value = -1.1 }, -- dB
   clipcal = { min = -1000.0, max = 12, value = -3, volatile=true }, -- dB
   pepino_clipcal = { min = -1000.0, max = 12, value = -5.5, volatile=true }, -- dB
   stenh_dif_rel = { min = 0.1, max = 100000, value = 500 }, -- ms
   dist_mtr_attack = { min = 0.0001, max = 1, value = 0.00125, volatile = true}, -- unitless
   dist_mtr_gain = { min = -1000, max = 10, value = 5.75, volatile = true}, -- dB
   v_hold = { val_list = { 0, 1 }, value = 0, volatile=true },
      -- 0 = normal, 1 = Dry Voice Hold Mode
   sent_drv = { min = -1000, max = 10, value = 3.0}, -- dB
   sen_comp_gain = { min = -1000, max = 20, value = -0.0, volatile = true}, -- dB
   voi_comp_gain = { min = -1000, max = 20, value = -15.0, volatile = true}, -- dB
   mus_comp_gain = { min = -1000, max = 20, value = -6.5, volatile = true}, -- dB
   mus_bp1_gain = { min = -1000, max = 20, value = 4.5, volatile = true}, -- dB
   mus_bp2_gain = { min = -1000, max = 20, value = 4.5, volatile = true}, -- dB
   bp_mode = { val_list = { 0, 1, 2 }, value = 0 },
   -- 0 = normal, 1 = bass_hp1, 2 = bassclip_hp
   mus_comp_ratio =  { min = 0.0001, max = 1.0, value = 0.5, volatile = true}, -- unitless
   lim_vatt = { min = 0.1, max = 174760, value = 5, volatile=true }, -- ms
   lim_vrel = { min = 0.1, max = 174760, value = 500, volatile=true }, -- ms 
   clipper_out_cal = { min = -1000, max = 20, value = 7.0, volatile = true}, -- dB
   clipper_be_cal = { min = -1000, max = 20, value = 0.0, volatile = true}, -- dB
   clipper_V3be_cal = { min = -1000, max = 20, value = -1.0, volatile = true}, -- dB
   clipper_V3fe_cal = { min = -1000, max = 20, value = 1.0, volatile = true}, -- dB
   clipper_emph = { min = -1000, max = 20, value = 0.0, volatile = true}, -- dB
   clipper_spark = { min = -1000, max = 20, value = 0.0 }, -- dB 

--------------------------LL  Output Mix Controls------------------------------------
   shagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   hiagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   mhagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   mlagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   loagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB
 
   APS_djcal = { min = -1000.0, max = 0.0, value = -50, volatile=true }, -- dB  
   dj_rngmast = { min = -1000.0, max = 12.0, value = -20 }, -- dB
   dj_lolimrng = { min = -1000.0, max = 12.0, value = 0 }, -- dB
   dj_mdlimrng = { min = -1000.0, max = 12.0, value = 0 }, -- dB
   dj_prlimrng = { min = -1000.0, max = 12.0, value = 0 }, -- dB
   dj_hilimrng = { min = -1000.0, max = 12.0, value = 0 }, -- dB
   
   APS_djomast = { min = -1000.0, max = 12.0, value = -20 }, -- dB
   djhimix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   djprmix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   djmdmix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   djlomix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   dj_ocal = { min = -1000.0, max = 12.0, value = -1.0, volatile=true }, -- dB 

   APS_djdrvcal = { min = -1000.0, max = 12.0, value = -25, volatile=true }, 
   -- dB

   djlim_attack = { min = 1/1024, max = 1024, value = 0.5 }, -- unitless
   djlim_release = { min = 1/1024, max = 1024, value = 1 }, -- unitless

   djshlim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   djprlim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   djmdlim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms
   djlolim_rel_cal = { min = 0.1, max = 174760, value = 400 }, -- ms

   djshlim_att_cal = { min = 0.1, max = 174760, value = 200 }, -- ms 
   djprlim_att_cal = { min = 0.1, max = 174760, value = 200 }, -- ms
   djmdlim_att_cal = { min = 0.1, max = 174760, value = 200 }, -- ms
   djlolim_att_cal = { min = 0.1, max = 174760, value = 200 }, -- ms

   dj_clip =  { min = -1000.0, max = 7.0, value = 2.0 }, -- dB 
   
   APS_dj_cal = { min = -1000.0, max = 30.0, value = 0 }, -- dB 
   APS_dj_bclip = { min = -20, max = 12.0, value = -2 }, --dB

----------------------------- HD Section---------------------------------------

   HD_fnl_drive =  { min = -1000.0, max = 122.0, value = -2.0 }, -- dB
   HD_fnl_opt =  { min = -1000.0, max = 122.0, value = -1.6, volatile=true }, -- dB

   HD_ftc_release = { min = 0.1, max = 174760, value = 35 }, -- ms
   hdlim_density = {min = 0.0001, max = 1.0, value = 0.45, volatile=true }, -- unitless

   HD_sensus_sens =  { min = -1000.0, max = 122.0, value = 0.0 }, -- dB
   HD_sensus_freq =  { min = 1000, max = 20000, value = 20000 }, -- Hertz

   hd_arbmode = { val_list = { 0, 1 },
   		       	   value = 1 }, -- 1 sends watermark to HD output

   
   hdfnl_plttc_drive1 = { min = 0, max = 1, value = 0.95, volatile=true }, -- unitless
   hdfnl_plttc_out = { min = 0, max = 1, value = 0.5, volatile=true }, -- unitless
   hdfnl_platt =  { min = 0.1, max = 174760, value = 380, volatile=true }, -- ms

---------------------------- Solar Plexus -----------------------------------

   spl_half_f_gain = { min = -1000, max = 0, value = -4.1 },  -- dB
   spl_level = { min = 0, max = 24, value = 0 }, -- dB of enhancement
   -- Note that the above works like a shelving EQ, so 0dB gives no effect.
   spl_engage = { val_list = { 0, 1 }, value = 0 }, -- 0 = bypass 1 = engage


-- Clipper Bypass for Devel Work

   clipper_bypass = { val_list = { 0, 1 }, value = 0, volatile=true }, -- 0 = normal 1 = Bypass

---- test tone

   test_tone = { val_list = { 1, 2, 3, 4, 5 }, value = 1, volatile=true }, 
   ---- enumerated: 1 = normal operation, 2 = tone on L, 3 = tone on R,
   ----   4 = tone on L+R, 5 = tone on L-R
   ---- This variable is not saved (volatile) because we want to make a
   ---- test tone mode that stands apart from any preset or I/O config.
   tone_cal = { min = -1000, max = -12, value = -13.105, volatile=true }, -- dB




-- Insert Point Tone
   ins_t_mode = { val_list = { 0, 1 }, value = 0, volatile=true }, -- 0 = bypass 1 = Tone on





----------------- Removed Params - here to prevent GUI errors----------------

   HD_fnl_release =  { min = 0.1, max = 174760, value = 10000 }, -- ms

  sllim_xovr= { val_list = { 1, 2, 3, 4 },
   		       	   value = 3 },
   -- 1 = 150Hz, 2 = 120Hz, 3 = 110Hz

  lolim_xovr = { val_list = { 1, 2 },
   		       	   value = 2 },
   -- 1 = 420Hz, 2 = 330Hz


   wbagc_acc_rel = { min = 10, max = 1000, value = 10 }, -- release acceleration factor

-------------------------------------------------




}

